@@ -3,6 +3,7 @@ import time
 from base64 import b64decode
 import asyncio
 from math import ceil
+from typing import List
 
 from tonsdk.boc import Cell
 from tonsdk.utils import Address, bytes_to_b64str, b64str_to_bytes
@@ -34,7 +35,7 @@ async def get_owner(client: TonlibClient, addr: str):
     return a.to_string()
 
 
-def get_items(client: list[TonlibClient] or TonlibClient, addresses: list, filename_with_nft_metadata=None, max_requests: int = 1000):
+def get_items(client: List[TonlibClient] or TonlibClient, addresses: list, filename_with_nft_metadata=None, max_requests: int = 1000):
     if filename_with_nft_metadata and 'json' not in filename_with_nft_metadata:
         raise Exception('Only .json files are expected')
     elif filename_with_nft_metadata:
@@ -76,7 +77,7 @@ async def get_item(client: TonlibClient, addr: str, nft_items: list, items: dict
     if items:
         if str(x['index']) in items:
             content = items[str(x['index'])]
-            # print(time.time() - s)
+            print(time.time() - s)
         else:
             content = await get(content_url)
     else:
